@@ -266,7 +266,12 @@ class Structure:
                 )
             )
         with self._get_file_stream(route) as stream:
-            stream.write(strings.MAIN_ROUTER_FILE)
+            stream.write(
+                strings.MAIN_ROUTER_FILE.format(
+                    project_folder=self.project_folder,
+                    providers_folder=self.providers_folder,
+                )
+            )
 
     def create_dependencies_folder(self):
         self.files.create_dir(
@@ -359,6 +364,7 @@ class Structure:
                     project_folder=self.project_folder,
                     providers_folder=self.providers_folder,
                     exceptions_folder=self.exceptions_folder,
+                    project_as_title=self.pyproject_toml.get_project_title(),
                 )
             )
 
