@@ -175,6 +175,15 @@ class DatabaseProvider:
             async with session.begin():
                 yield session
 
+    async def healthcheck(self):
+        try:
+            async with self.begin() as session:
+                await session.execute("SELECT 1")
+            return True
+        except:
+            settings.logger.exception()
+            return False
+
 """
 
 SETTINGS_FILE = """
@@ -186,7 +195,7 @@ from {project_folder}.core.log import set_logger
 from {project_folder}.{utils_folder} import Env, Environment
 
 BASE_DIR = Path(__file__).resolve().parent.parent
-if (env_file:=(BASE_DIR / ".env")).exists():
+if (env_file:=(BASE_DIR.parent / ".env")).exists():
     load_dotenv(env_file)
 
 environment = Environment()
@@ -310,9 +319,17 @@ DUNDER_ROUTES = """from .{main_router_file} import router
 __all__ = ["router"] 
 """
 
-MAIN_ROUTER_FILE = """from fastapi import APIRouter
+MAIN_ROUTER_FILE = """from fastapi import APIRouter, Depends
+
+from {project_folder}.{providers_folder} import DatabaseProvider
+from .dependencies import get_database_provider
+
 router = APIRouter()
 
+@router.get("/health")
+async def validate_health(database_provider: DatabaseProvider = Depends(get_database_provider)):
+    return {{"status":await database_provider.healthcheck()}}
+
 """
 
 DUNDER_DEPENDENCIES = """from ._http import get_http_provider
@@ -584,7 +601,7 @@ def create_shutdown_handler(_app: FastAPI):
 
 def get_application(prefix: str = ""):
     _app = FastAPI(
-        title="Adapty Event Listener",
+        title="{project_as_title}",
         openapi_url=f"{{prefix}}/openapi.json",
         docs_url=f"{{prefix}}/docs",
         redoc_url=f"{{prefix}}/redoc",
